@@ -68,11 +68,13 @@
 #include <KConfigGroup>
 #include <QDialogButtonBox>
 #include <QPushButton>
+#include <QToolButton>
 
 using namespace KIdentityManagement;
 using namespace KCalCore;
 using namespace KCalUtils;
 
+// fallback defaults
 static int defSuspendVal = 5;
 static int defSuspendUnit = AlarmDialog::SuspendInMinutes;
 
@@ -85,6 +87,7 @@ public:
         , mNotified(false)
     {
     }
+    ~ReminderTreeItem() override {}
 
     bool operator<(const QTreeWidgetItem &other) const override;
 
@@ -142,9 +145,13 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup generalConfig(config, "General");
     QPoint pos = generalConfig.readEntry("Position", QPoint(0, 0));
+
+    int defSuspendVal = generalConfig.readEntry("DefaultSuspendValue", defSuspendVal);
     int suspendVal = generalConfig.readEntry("SuspendValue", defSuspendVal);
-    SuspendUnit suspendUnit
-        = static_cast<SuspendUnit>(generalConfig.readEntry("SuspendUnit", defSuspendUnit));
+
+    int defSuspendUnit = generalConfig.readEntry("SuspendUnit", defSuspendUnit);
+    SuspendUnit suspendUnit = static_cast<SuspendUnit>(generalConfig.readEntry("SuspendUnit",
+                                                                               defSuspendUnit));
 
     QWidget *topBox = new QWidget(this);
     if (!pos.isNull()) {
@@ -153,10 +160,10 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     }
     setWindowTitle(i18nc("@title:window", "Reminders"));
     setWindowIcon(QIcon::fromTheme(QStringLiteral("korgac")));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok, this);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(this);
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(topBox);
-    mOkButton = buttonBox->button(QDialogButtonBox::Ok);
+    mOkButton = new QToolButton;
     mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     mUser1Button = new QPushButton;
     buttonBox->addButton(mUser1Button, QDialogButtonBox::ActionRole);
@@ -167,22 +174,36 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     connect(buttonBox, &QDialogButtonBox::accepted, this, &AlarmDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &AlarmDialog::reject);
     mainLayout->addWidget(buttonBox);
+    buttonBox->addButton(mOkButton, QDialogButtonBox::ActionRole);
 
     mUser3Button->setText(i18nc("@action:button", "Dismiss Reminder"));
     mUser3Button->setToolTip(i18nc("@info:tooltip",
                                    "Dismiss the reminders for the selected incidences"));
+    mUser3Button->setWhatsThis(i18nc("@info:whatsthis",
+                                     "Press this button to dismiss the currently selected incidence.  "
+                                     "All non-selected non-incidences will be unaffected."));
+
     mUser2Button->setText(i18nc("@action:button", "Dismiss All"));
     mUser2Button->setToolTip(i18nc("@info:tooltip",
                                    "Dismiss the reminders for all listed incidences"));
+    mUser2Button->setWhatsThis(i18nc("@info:whatsthis",
+                                     "Press this button to dismiss all the listed incidences."));
     mUser1Button->setText(i18nc("@action:button", "Edit..."));
     mUser1Button->setToolTip(i18nc("@info:tooltip",
                                    "Edit the selected incidence"));
+    mUser1Button->setWhatsThis(i18nc("@info::whatsthis",
+                                     "Press this button if you want to edit the selected incidence.  "
+                                     "A dialog will popup allowing you to edit the incidence."));
     mOkButton->setText(i18nc("@action:button", "Suspend"));
     mOkButton->setToolTip(i18nc("@info:tooltip",
                                 "Suspend the reminders for the selected incidences "
                                 "by the specified interval"));
+    mOkButton->setWhatsThis(i18nc("@info:whatsthis",
+                                  "Press this button to suspend the currently selected incidences.  "
+                                  "The suspend interval is configurable by the Suspend duration settings."));
 
-    // Try to keep the dialog small and non-obtrusive.
+    // Initial dialog should be rather small.
+    // However, the user can resize and the window geometry is saved/restored.
     setMinimumWidth(575);
     setMinimumHeight(300);
 
@@ -232,7 +253,7 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     mDetailView->setDefaultMessage(s);
     mTopLayout->addWidget(mDetailView);
     mDetailView->hide();
-    mLastItem = 0;
+    mLastItem = nullptr;
 
     QWidget *suspendBox = new QWidget(topBox);
     QHBoxLayout *suspendBoxHBoxLayout = new QHBoxLayout(suspendBox);
@@ -271,9 +292,29 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
               "Each reminder for the selected incidences will be suspended "
               "using this time unit. You can set the number of time units "
               "in the adjacent number entry input."));
-
     mSuspendUnit->setCurrentIndex(static_cast<int>(suspendUnit));
 
+    mSuspendMenu = new QMenu();
+    mSuspendMenu->setToolTipsVisible(true);
+    mOkButton->setMenu(mSuspendMenu);
+
+    QAction *mResetSuspendAction = new QAction(i18nc("@action:inmenu", "Reset"));
+    connect(mResetSuspendAction, &QAction::triggered, this, &AlarmDialog::resetSuspend);
+    mResetSuspendAction->setToolTip(i18nc("@info:tooltip",
+                                          "Reset the suspend time to the default value"));
+    mResetSuspendAction->setWhatsThis(i18nc("@info:whatsthis",
+                                            "Reset the suspend time to the default value"));
+    mSuspendMenu->addAction(mResetSuspendAction);
+
+    QAction *mSetDefaultSuspendAction = new QAction(i18nc("@action:inmenu", "Set as Default"));
+    connect(mSetDefaultSuspendAction, &QAction::triggered, this, &AlarmDialog::setDefaultSuspend);
+    mSetDefaultSuspendAction->setToolTip(i18nc("@info:tooltip",
+                                               "Set the current suspend time as the new default"));
+    mSetDefaultSuspendAction->setWhatsThis(i18nc("@info:whatsthis",
+                                                 "Press this button to set the current suspend "
+                                                 "time as the new default value"));
+    mSuspendMenu->addAction(mSetDefaultSuspendAction);
+
     connect(&mSuspendTimer, &QTimer::timeout, this, &AlarmDialog::wakeUp);
 
     connect(mOkButton, &QPushButton::clicked, this, &AlarmDialog::slotOk);
@@ -364,6 +405,18 @@ void AlarmDialog::addIncidence(const Akonadi::Item &incidenceitem, const QDateTi
     slotSave();
 }
 
+void AlarmDialog::resetSuspend()
+{
+    mSuspendSpin->setValue(defSuspendVal);    // default suspend duration
+    mSuspendUnit->setCurrentIndex(defSuspendUnit);
+}
+
+void AlarmDialog::setDefaultSuspend()
+{
+    defSuspendVal = mSuspendSpin->value();
+    defSuspendUnit = mSuspendUnit->currentIndex();
+}
+
 void AlarmDialog::slotOk()
 {
     suspend();
@@ -554,7 +607,7 @@ void AlarmDialog::show()
     QTreeWidgetItemIterator it(mIncidenceTree);
     while (*it) {
         ReminderTreeItem *item = static_cast<ReminderTreeItem *>(*it);
-        if (!item->mNotified) {
+        if (!item->mNotified && !item->isDisabled()) {
             (*it)->setSelected(true);
             break;
         }
@@ -624,9 +677,9 @@ void AlarmDialog::eventNotification()
                 QString program = alarm->programFile();
 
                 // if the program name contains spaces escape it
-                if (program.contains(QLatin1Char(' '))
-                    && !(program.startsWith(QLatin1Char('\"'))
-                         && program.endsWith(QLatin1Char('\"')))) {
+                if (program.contains(QLatin1Char(' ')) &&
+                    !(program.startsWith(QLatin1Char('\"')) &&
+                      program.endsWith(QLatin1Char('\"')))) {
                     program = QLatin1Char('\"') + program + QLatin1Char('\"');
                 }
 
@@ -744,6 +797,8 @@ void AlarmDialog::slotSave()
 
     generalConfig.writeEntry("Reminders", numReminders);
     generalConfig.writeEntry("Position", pos());
+    generalConfig.writeEntry("DefaultSuspendValue", defSuspendVal);
+    generalConfig.writeEntry("DefaultSuspendUnit", defSuspendUnit);
     generalConfig.writeEntry("SuspendValue", mSuspendSpin->value());
     generalConfig.writeEntry("SuspendUnit", mSuspendUnit->currentIndex());
 
@@ -836,8 +891,8 @@ void AlarmDialog::showDetails(QTreeWidgetItem *item)
         mDetailView->setIncidence(Akonadi::Item());
     } else {
         if (!reminderItem->mDisplayText.isEmpty()) {
-            const QString txt = QLatin1String("<qt><p><b>") + reminderItem->mDisplayText
-                                + QLatin1String("</b></p></qt>");
+            const QString txt =
+                QLatin1String("<qt><p><b>") + reminderItem->mDisplayText + QLatin1String("</b></p></qt>");
             mDetailView->setHeaderText(txt);
         } else {
             mDetailView->setHeaderText(QString());
@@ -853,9 +908,8 @@ void AlarmDialog::update()
     const ReminderList selection = selectedItems();
     if (!selection.isEmpty()) {
         ReminderTreeItem *item = selection.first();
-        mUser1Button->setEnabled((mCalendar->hasRight(item->mIncidence,
-                                                      Akonadi::Collection::CanChangeItem))
-                                 && (selection.count() == 1));
+        mUser1Button->setEnabled(
+            (mCalendar->hasRight(item->mIncidence, Akonadi::Collection::CanChangeItem)) && (selection.count() == 1));
         toggleDetails(item);
     }
 }
@@ -907,13 +961,10 @@ void AlarmDialog::slotCalendarChanged()
 
             // Yes, alarms can be empty, if someone edited the incidence and removed all alarms
             if (!incidence->alarms().isEmpty()) {
-                const auto dateTime
-                    = triggerDateForIncidence(incidence, item->mRemindAt, displayStr);
-
+                const auto dateTime = triggerDateForIncidence(incidence, item->mRemindAt, displayStr);
                 const QString summary = cleanSummary(incidence->summary());
 
-                if (displayStr != item->text(1) || summary != item->text(0)
-                    || item->mHappening != dateTime) {
+                if (displayStr != item->text(1) || summary != item->text(0) || item->mHappening != dateTime) {
                     item->setText(1, displayStr);
                     item->setText(0, summary);
                     item->mHappening = dateTime;
