@@ -25,10 +25,11 @@
 #define KORGAC_ALARMDIALOG_H
 
 #include <Akonadi/Calendar/ETMCalendar>
-#include <Item>
-#include <QDialog>
+
 #include <KCalCore/Incidence>
 
+#include <QDialog>
+#include <QMenu>
 #include <QPoint>
 #include <QTimer>
 
@@ -52,11 +53,10 @@ class QDateTime;
 class QTreeWidget;
 class QTreeWidgetItem;
 class QSpinBox;
-
+class QToolButton;
 class AlarmDialog : public QDialog
 {
     Q_OBJECT
-    Q_ENUMS(SuspendUnit)
 
 public:
     /**
@@ -68,6 +68,7 @@ public:
         SuspendInDays = 2,     ///< Suspend time is in days
         SuspendInWeeks = 3     ///< Suspend time is in weeks
     };
+    Q_ENUM(SuspendUnit)
 
     explicit AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent = nullptr);
     ~AlarmDialog();
@@ -82,6 +83,8 @@ public Q_SLOTS:
     void slotUser1(); // edit
     void slotUser2(); // dismiss all
     void slotUser3(); // dismiss selected
+    void resetSuspend(); //reset the suspend value to the default
+    void setDefaultSuspend(); //set current suspend value as the default
     void slotSave();
     void wakeUp();
     void show();
@@ -140,12 +143,15 @@ private:
     QPoint mPos;
     QSpinBox *mSuspendSpin = nullptr;
     KComboBox *mSuspendUnit = nullptr;
+    QMenu *mSuspendMenu = nullptr;
+    QAction *mResetSuspendAction = nullptr;
+    QAction *mSetDefaultSuspendAction = nullptr;
     QTimer mSuspendTimer;
     QTreeWidgetItem *mLastItem = nullptr;
     QPushButton *mUser1Button = nullptr;
     QPushButton *mUser2Button = nullptr;
     QPushButton *mUser3Button = nullptr;
-    QPushButton *mOkButton = nullptr;
+    QToolButton *mOkButton = nullptr;
 };
 
 #endif
