@@ -339,8 +339,8 @@ void KOViewManager::connectView(KOrg::BaseView *view)
     connect(view, &BaseView::endMultiModify,
             mMainView, &CalendarView::endMultiModify);
 
-    connect(mMainView, SIGNAL(newIncidenceChanger(Akonadi::IncidenceChanger *)),
-            view, SLOT(setIncidenceChanger(Akonadi::IncidenceChanger *)));
+    connect(mMainView, SIGNAL(newIncidenceChanger(Akonadi::IncidenceChanger*)),
+            view, SLOT(setIncidenceChanger(Akonadi::IncidenceChanger*)));
 
     view->setIncidenceChanger(mMainView->incidenceChanger());
 }
@@ -441,13 +441,12 @@ void KOViewManager::showListView()
 
 void KOViewManager::showAgendaView()
 {
-    const bool showBoth
-        = KOPrefs::instance()->agendaViewCalendarDisplay() == KOPrefs::AllCalendarViews;
-    const bool showMerged
-        = showBoth || KOPrefs::instance()->agendaViewCalendarDisplay() == KOPrefs::CalendarsMerged;
-    const bool showSideBySide
-        = showBoth
-          || KOPrefs::instance()->agendaViewCalendarDisplay() == KOPrefs::CalendarsSideBySide;
+    const bool showBoth =
+        KOPrefs::instance()->agendaViewCalendarDisplay() == KOPrefs::AllCalendarViews;
+    const bool showMerged =
+        showBoth || KOPrefs::instance()->agendaViewCalendarDisplay() == KOPrefs::CalendarsMerged;
+    const bool showSideBySide =
+        showBoth || KOPrefs::instance()->agendaViewCalendarDisplay() == KOPrefs::CalendarsSideBySide;
 
     QWidget *parent = mMainView->viewStack();
     if (showBoth) {
@@ -552,7 +551,7 @@ void KOViewManager::selectNextX()
 void KOViewManager::showTodoView()
 {
     if (!mTodoView) {
-        mTodoView = new KOTodoView(false /*not sidebar*/, mMainView->viewStack());
+        mTodoView = new KOTodoView(false/*not sidebar*/, mMainView->viewStack());
         mTodoView->setCalendar(mMainView->calendar());
         mTodoView->setIdentifier("DefaultTodoView");
         mTodoView->setCalendar(mMainView->calendar());
