@@ -39,7 +39,7 @@ class KOAgendaView : public KOEventView
     Q_OBJECT
 public:
     explicit KOAgendaView(QWidget *parent = nullptr, bool isSideBySide = false);
-    virtual ~KOAgendaView();
+    ~KOAgendaView() override;
 
     /** Returns maximum number of days supported by the koagendaview */
     int maxDatesHint() const override;
@@ -89,7 +89,8 @@ public Q_SLOTS:
     void showIncidences(const Akonadi::Item::List &incidenceList, const QDate &date) override;
 
     void changeIncidenceDisplayAdded(const Akonadi::Item &incidence);
-    void changeIncidenceDisplay(const Akonadi::Item &incidence, Akonadi::IncidenceChanger::ChangeType) override;
+    void changeIncidenceDisplay(const Akonadi::Item &incidence,
+                                Akonadi::IncidenceChanger::ChangeType) override;
 
     void clearSelection() override;
 
