@@ -30,11 +30,9 @@
 #include <KCalCore/FreeBusy>
 #include <QDialog>
 
+class Ui_quickview;
 
-class  Ui_quickview;
-
-namespace EventViews
-{
+namespace EventViews {
 class AgendaView;
 }
 
@@ -43,7 +41,7 @@ class Quickview : public QDialog
     Q_OBJECT
 public:
     Quickview(const KPIM::Person &person, const Akonadi::Collection &col);
-    virtual ~Quickview();
+    ~Quickview() override;
 
 private Q_SLOTS:
     void onTodayClicked();
